exceptiontools.ExtraNamedComponentError
=======================================

.. abjad-lineage:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError

.. autoclass:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNamedComponentError.ExtraNamedComponentError.__unicode__
   :noindex:
